@@ -1,12 +1,16 @@
 use std::path::PathBuf;
 
-use clap::{Parser, StructOpt};
+use clap::Parser;
 
 use sifis_generate::{create_project, Templates};
+use tracing_subscriber::EnvFilter;
 
-#[derive(StructOpt, Debug)]
+#[derive(Parser, Debug)]
 struct Opts {
-    #[structopt(subcommand)]
+    /// Output the generated paths as they are produced
+    #[clap(short, long, global = true)]
+    verbose: bool,
+    #[clap(subcommand)]
     cmd: Cmd,
 }
 
@@ -20,7 +24,7 @@ lazy_static::lazy_static! {
     static ref TEMPLATES_INFO: String = Templates::info();
 }
 
-#[derive(StructOpt, Debug)]
+#[derive(Parser, Debug)]
 enum Cmd {
     /// Create a new project
     #[structopt(after_help = TEMPLATES_INFO.as_str())]
@@ -40,6 +44,22 @@ enum Cmd {
 fn main() -> anyhow::Result<()> {
     let opts = Opts::parse();
 
+    let filter_layer = EnvFilter::try_from_default_env()
+        .or_else(|_| {
+            if opts.verbose {
+                EnvFilter::try_new("debug")
+            } else {
+                EnvFilter::try_new("info")
+            }
+        })
+        .unwrap();
+
+    tracing_subscriber::fmt()
+        .without_time()
+        .with_env_filter(filter_layer)
+        .with_writer(std::io::stderr)
+        .init();
+
     match opts.cmd {
         Cmd::New {
             template,
