@@ -19,5 +19,5 @@ pub(crate) fn comment_license(
 }
 
 pub(crate) fn hypens_to_underscores(_state: &State, value: String) -> Result<String, Error> {
-    Ok(value.replace("-", "_"))
+    Ok(value.replace('-', "_"))
 }
