@@ -9,6 +9,7 @@ use anyhow::{bail, Result};
 use arg_enum_proc_macro::ArgEnum;
 use minijinja::value::Value;
 use minijinja::{Environment, Source};
+use tracing::debug;
 
 use filters::*;
 use toolchain::*;
@@ -23,8 +24,8 @@ pub enum Templates {
     #[arg_enum(name = "meson-c++")]
     MesonCpp,
     /// Generate a pyproject.toml project using Python as main language
-    #[arg_enum(name = "setuptools")]
-    SetupTools,
+    #[arg_enum(name = "poetry")]
+    Poetry,
     /// Generate a maven project using Java as main language
     #[arg_enum(name = "maven")]
     Maven,
@@ -70,6 +71,7 @@ impl SifisTemplate {
 
         // Create dirs
         for dir in dirs {
+            debug!("Creating {}", dir.display());
             create_dir_all(dir)?
         }
 
@@ -79,6 +81,7 @@ impl SifisTemplate {
 
         // Fill in templates
         for (path, template_name) in files {
+            debug!("Creating {}", path.display());
             let template = env.get_template(template_name)?;
             let filled_template = template.render(&context)?;
             write(path, filled_template)?;
@@ -185,7 +188,7 @@ pub fn create_project(template_type: Templates, project_path: &Path, license: &s
             Maven::create(group).build(&project_path, project_name)
         }
         Templates::CargoCI => Cargo::create_ci().build(project_path, project_name),
-        Templates::SetupTools => SetupTools::create().build(project_path, project_name),
+        Templates::Poetry => Poetry::create().build(project_path, project_name),
         Templates::YarnCI => Yarn::create_ci().build(project_path, project_name),
     };
 
